@@ -1,12 +1,14 @@
 """Common code for DNS Authenticator Plugins built on Lexicon."""
 import logging
+from typing import Any
+from typing import Dict
+from typing import Mapping
+from typing import Optional
+from typing import Union
 
 from requests.exceptions import HTTPError
 from requests.exceptions import RequestException
 
-from acme.magic_typing import Any  # pylint: disable=unused-import, no-name-in-module
-from acme.magic_typing import Dict  # pylint: disable=unused-import, no-name-in-module
-from acme.magic_typing import Union  # pylint: disable=unused-import, no-name-in-module
 from certbot import errors
 from certbot.plugins import dns_common
 
@@ -17,21 +19,23 @@ from certbot.plugins import dns_common
 # if Lexicon is not available, obviously.
 try:
     from lexicon.config import ConfigResolver
+    from lexicon.providers.base import Provider
 except ImportError:
-    ConfigResolver = None  # type: ignore
+    ConfigResolver = None
+    Provider = None
 
 logger = logging.getLogger(__name__)
 
 
-class LexiconClient(object):
+class LexiconClient:
     """
     Encapsulates all communication with a DNS provider via Lexicon.
     """
 
-    def __init__(self):
-        self.provider = None
+    def __init__(self) -> None:
+        self.provider: Provider
 
-    def add_txt_record(self, domain, record_name, record_content):
+    def add_txt_record(self, domain: str, record_name: str, record_content: str) -> None:
         """
         Add a TXT record using the supplied information.
 
@@ -43,12 +47,12 @@ class LexiconClient(object):
         self._find_domain_id(domain)
 
         try:
-            self.provider.create_record(type='TXT', name=record_name, content=record_content)
+            self.provider.create_record(rtype='TXT', name=record_name, content=record_content)
         except RequestException as e:
             logger.debug('Encountered error adding TXT record: %s', e, exc_info=True)
             raise errors.PluginError('Error adding TXT record: {0}'.format(e))
 
-    def del_txt_record(self, domain, record_name, record_content):
+    def del_txt_record(self, domain: str, record_name: str, record_content: str) -> None:
         """
         Delete a TXT record using the supplied information.
 
@@ -65,11 +69,11 @@ class LexiconClient(object):
             return
 
         try:
-            self.provider.delete_record(type='TXT', name=record_name, content=record_content)
+            self.provider.delete_record(rtype='TXT', name=record_name, content=record_content)
         except RequestException as e:
             logger.debug('Encountered error deleting TXT record: %s', e, exc_info=True)
 
-    def _find_domain_id(self, domain):
+    def _find_domain_id(self, domain: str) -> None:
         """
         Find the domain_id for a given domain.
 
@@ -92,32 +96,33 @@ class LexiconClient(object):
 
                 return  # If `authenticate` doesn't throw an exception, we've found the right name
             except HTTPError as e:
-                result = self._handle_http_error(e, domain_name)
+                result1 = self._handle_http_error(e, domain_name)
 
-                if result:
-                    raise result
+                if result1:
+                    raise result1
             except Exception as e:  # pylint: disable=broad-except
-                result = self._handle_general_error(e, domain_name)
+                result2 = self._handle_general_error(e, domain_name)
 
-                if result:
-                    raise result  # pylint: disable=raising-bad-type
+                if result2:
+                    raise result2  # pylint: disable=raising-bad-type
 
         raise errors.PluginError('Unable to determine zone identifier for {0} using zone names: {1}'
                                  .format(domain, domain_name_guesses))
 
-    def _handle_http_error(self, e, domain_name):
+    def _handle_http_error(self, e: HTTPError, domain_name: str) -> Optional[errors.PluginError]:
         return errors.PluginError('Error determining zone identifier for {0}: {1}.'
                                   .format(domain_name, e))
 
-    def _handle_general_error(self, e, domain_name):
+    def _handle_general_error(self, e: Exception, domain_name: str) -> Optional[errors.PluginError]:
         if not str(e).startswith('No domain found'):
             return errors.PluginError('Unexpected error determining zone identifier for {0}: {1}'
                                       .format(domain_name, e))
         return None
 
 
-def build_lexicon_config(lexicon_provider_name, lexicon_options, provider_options):
-    # type: (str, Dict, Dict) -> Union[ConfigResolver, Dict]
+def build_lexicon_config(lexicon_provider_name: str,
+                         lexicon_options: Mapping[str, Any], provider_options: Mapping[str, Any]
+                         ) -> Union[ConfigResolver, Dict[str, Any]]:
     """
     Convenient function to build a Lexicon 2.x/3.x config object.
     :param str lexicon_provider_name: the name of the lexicon provider to use
@@ -126,14 +131,14 @@ def build_lexicon_config(lexicon_provider_name, lexicon_options, provider_option
     :return: configuration to apply to the provider
     :rtype: ConfigurationResolver or dict
     """
-    config = {'provider_name': lexicon_provider_name}  # type: Dict[str, Any]
+    config: Union[ConfigResolver, Dict[str, Any]] = {'provider_name': lexicon_provider_name}
     config.update(lexicon_options)
     if not ConfigResolver:
         # Lexicon 2.x
         config.update(provider_options)
     else:
         # Lexicon 3.x
-        provider_config = {}
+        provider_config: Dict[str, Any] = {}
         provider_config.update(provider_options)
         config[lexicon_provider_name] = provider_config
         config = ConfigResolver().with_dict(config).with_env()
